<?php

/**
 * @file
 * Contains \Drupal\yearonly\Plugin\Field\FieldType\YearOnlyItem.
 */

namespace Drupal\yearonly\Plugin\Field\FieldType;

use Drupal\Core\TypedData\DataDefinition;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldItemInterface;

/**
 * Plugin implementation of the 'yearonly' field type.
 *
 * @FieldType(
 * id = "yearonly",
 * label = @Translation("Year only"),
 * description = @Translation("This field provide the ways to collect year only in provided date range."),
 * default_widget = "yearonly_default",
 * default_formatter = "yearonly_default",
 * )
 */
class YearOnlyItem extends FieldItemBase implements FieldItemInterface {
  /**
   *
   * {@inheritdoc}
   *
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return array(
      'columns' => array(
        'value' => array(
          'type' => 'varchar',
          'length' => 50,
        ),
      ),
      'indexes' => array(
        'value' => array(
          'value',
        ),
      ),
    );
  }

  /**
   *
   * {@inheritdoc}
   *
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties = array();
    $properties['value'] = DataDefinition::create('string');
    return $properties;
  }

  /**
   *
   * {@inheritdoc}
   *
   */
  public function isEmpty() {
    $value = $this->get('value')->getValue();
    return $value === NULL || $value === '';
  }

  /**
   *
   * {@inheritdoc}
   *
   */
  public static function defaultFieldSettings() {
    return array(
      'yearonly_from' => '',
      'yearonly_to' => '',
    ) + parent::defaultFieldSettings();
  }

  /**
   *
   * {@inheritdoc}
   *
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
    $element = array();

    $element['#markup'] = '<strong>'.t('Select yearonly field range. This field will display the range as selected below on form.').'</strong>';

    $options = array_combine(range(1900, date('Y') - 1), range(1900, date('Y') - 1));
    $element['yearonly_from'] = array(
      '#type' => 'select',
      '#title' => t('From'),
      '#default_value' => $this->getSetting('yearonly_from'),
      '#options' => $options,
      '#description' => t('Select starting year.'),
      '#weight' => 1,
    );

    $options = array(
      'now' => 'NOW',
    );
    $options += array_combine(range(date('Y') + 1, date('Y') + 50), range(date('Y') + 1, date('Y') + 50));
    $element['yearonly_to'] = array(
      '#type' => 'select',
      '#title' => t('To'),
      '#default_value' => $this->getSetting('yearonly_to'),
      '#options' => $options,
      '#description' => t('Select last year.'),
      '#weight' => 1,
    );

    return $element;
  }
}
